@@ -4,6 +4,8 @@ from hammurabi.config import config
 from hammurabi.law import Law
 from hammurabi.pillar import Pillar
 from hammurabi.preconditions.base import Precondition
+from hammurabi.reporters.base import Reporter
+from hammurabi.reporters.json import JSONReporter
 from hammurabi.rules.attributes import ModeChanged, OwnerChanged
 from hammurabi.rules.base import Rule
 from hammurabi.rules.directories import (
@@ -37,4 +39,4 @@ from hammurabi.rules.yaml import (
     YAMLValueNotExists,
 )
 
-__version__ = "0.3.1"
+__version__ = "0.4.0"
