@@ -6,9 +6,11 @@ extensions for several online git based VCS.
 
 import logging
 from pathlib import Path
-from typing import Iterable, List, Union
+from typing import Iterable, List, Optional, Union
 
+from github3.pulls import ShortPullRequest  # type: ignore
 from github3.repos.repo import Repository  # type: ignore
+from github3.structs import GitHubIterator  # type: ignore
 
 from hammurabi.config import config
 from hammurabi.preconditions.base import Precondition
@@ -175,7 +177,7 @@ class PullRequestHelperMixin:  # pylint: disable=too-few-public-methods
             body.append(f"* {rule.name}")
 
             for chain in self.__get_chained_rules(rule, rule.get_rule_chain(rule)):
-                body.append(f"** {chain.name}")
+                body.append(f"  * {chain.name}")
 
         return body
 
@@ -201,29 +203,36 @@ class PullRequestHelperMixin:  # pylint: disable=too-few-public-methods
             "Below you can find the executed laws and information about them.",
         ]
 
-        for law in pillar.laws:
+        # Filter only those laws which has other rules than skipped ones.
+        actionable_laws = filter(lambda l: l.passed_rules + l.failed_rules, pillar.laws)
+
+        for law in actionable_laws:
             body.append(f"\n### {law.name}")
             body.append(law.description)
 
-            body.append("\n#### Passed rules")
-            body.extend(
-                self.__get_rules_body([rule for rule in law.rules if rule.made_changes])
-            )
+            if law.passed_rules:
+                body.append("\n<details>")
+                body.append("<summary>Passed rules</summary>\n")
+                body.extend(self.__get_rules_body(law.passed_rules))
+                body.append("</details>")
 
             if law.failed_rules:
-                body.append("\n#### Failed rules (manual fix is needed)")
+                body.append("\n<details open>")
+                body.append("<summary>Failed rules (manual fix needed)</summary>\n")
                 body.extend(self.__get_rules_body(law.failed_rules))
+                body.append("</details>")
 
         return "\n".join(body)
 
 
+# TODO: Move to a separate file as part of a new package if other VCS is supported
 class GitHubMixin(GitMixin, PullRequestHelperMixin):
     """
     Extending :class:`hammurabi.mixins.GitMixin` to be able to open pull requests
     on GitHub after changes are pushed to remote.
     """
 
-    def create_pull_request(self):
+    def create_pull_request(self) -> Optional[str]:
         """
         Create a PR on GitHub after the changes are pushed to remote. The pull
         request details (repository, branch) are set by the project
@@ -238,6 +247,9 @@ class GitHubMixin(GitMixin, PullRequestHelperMixin):
         +------------+--------------------------------------+
         | branch     | git_branch_name                      |
         +------------+--------------------------------------+
+
+        :return: Return the open (and updated) or opened PR's url
+        :rtype: Optional[str]
         """
 
         if not config.github:
@@ -251,17 +263,31 @@ class GitHubMixin(GitMixin, PullRequestHelperMixin):
             github_repo: Repository = config.github.repository(owner, repository)
 
             logging.info("Checking for opened pull request")
-            opened_pull_request = github_repo.pull_requests(
-                state="open", head=config.settings.git_branch_name, base="master"
+            opened_pull_requests: GitHubIterator[
+                ShortPullRequest
+            ] = github_repo.pull_requests(
+                state="open",
+                head=config.settings.git_branch_name,
+                base=config.settings.git_base_name,
             )
 
-            if opened_pull_request.count == -1:
+            if opened_pull_requests.count == -1:
                 description = self.generate_pull_request_body(config.settings.pillar)
 
                 logging.info("Opening pull request")
-                github_repo.create_pull(
+                response: ShortPullRequest = github_repo.create_pull(
                     title="[hammurabi] Update to match the latest baseline",
                     base=config.settings.git_base_name,
                     head=config.settings.git_branch_name,
                     body=description,
                 )
+
+                return response.url
+
+            # Return the last known PR url, it should be one
+            # anyways, so it is not an issue
+            return opened_pull_requests.last_url
+
+        # Although this return could be skipped, it is more
+        # explicit to have it here
+        return None
